Lignes d'azur : le Réseau de Transport de Nice Côte d'Azur - Horaires

Vous êtes à l'arrêt
INRIA
Horaires
Date : 25/01/2017
Il est 17h10 Actualiser
Ligne : 230
à l'approche direction Cathédrale-Vieille Ville
dans 11 min direction Cathédrale-Vieille Ville
dans 11 min direction Cathédrale-Vieille Ville
à 17h37 direction Gambetta / France
à 17h42 direction Cathédrale-Vieille Ville *
à 17h52 direction Cathédrale-Vieille Ville *
à 17h59 direction Cathédrale-Vieille Ville *
à 18h07 direction Gambetta / France *
Ligne : 233
dans 14 min direction Halte Routière de l'Ara
Ligne : 232
à 17h33 direction Carros Médiathèque *
* horaires théoriques